Table of Contents
-----------------
A small collection of examples.


.. toctree::
   :maxdepth: 1

   Induction motor <induction_machine.ipynb>
   Three Tank <three_tank.ipynb>
   Sensor placement <structure_only_sensorplacement.ipynb>
